@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::ClassStartup;
 
-our $DATE = '2016-04-14'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2016-06-23'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -35,7 +35,7 @@ Bencher::Scenario::Accessors::ClassStartup - Benchmark startup of classes using
 
 =head1 VERSION
 
-This document describes version 0.06 of Bencher::Scenario::Accessors::ClassStartup (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-04-14.
+This document describes version 0.07 of Bencher::Scenario::Accessors::ClassStartup (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-06-23.
 
 =head1 SYNOPSIS
 
@@ -81,39 +81,9 @@ L<Perl::Examples::Accessors::Scalar> 0.05
 
 =over
 
-=item * Perl::Examples::Accessors::Mouse (perl_code)
+=item * Perl::Examples::Accessors::Moose (perl_code)
 
-L<Perl::Examples::Accessors::Mouse>
-
-
-
-=item * Perl::Examples::Accessors::ClassAccessorArray (perl_code)
-
-L<Perl::Examples::Accessors::ClassAccessorArray>
-
-
-
-=item * Perl::Examples::Accessors::MojoBase (perl_code)
-
-L<Perl::Examples::Accessors::MojoBase>
-
-
-
-=item * Perl::Examples::Accessors::ClassXSAccessor (perl_code)
-
-L<Perl::Examples::Accessors::ClassXSAccessor>
-
-
-
-=item * Perl::Examples::Accessors::Moo (perl_code)
-
-L<Perl::Examples::Accessors::Moo>
-
-
-
-=item * Perl::Examples::Accessors::Array (perl_code)
-
-L<Perl::Examples::Accessors::Array>
+L<Perl::Examples::Accessors::Moose>
 
 
 
@@ -129,27 +99,15 @@ L<Perl::Examples::Accessors::Scalar>
 
 
 
-=item * Perl::Examples::Accessors::Moose (perl_code)
+=item * Perl::Examples::Accessors::MojoBase (perl_code)
 
-L<Perl::Examples::Accessors::Moose>
+L<Perl::Examples::Accessors::MojoBase>
 
 
 
-=item * Perl::Examples::Accessors::ClassXSAccessorArray (perl_code)
+=item * Perl::Examples::Accessors::ClassAccessorArray (perl_code)
 
-L<Perl::Examples::Accessors::ClassXSAccessorArray>
-
-
-
-=item * Perl::Examples::Accessors::Hash (perl_code)
-
-L<Perl::Examples::Accessors::Hash>
-
-
-
-=item * Perl::Examples::Accessors::ClassInsideOut (perl_code)
-
-L<Perl::Examples::Accessors::ClassInsideOut>
+L<Perl::Examples::Accessors::ClassAccessorArray>
 
 
 
@@ -159,39 +117,81 @@ L<Perl::Examples::Accessors::ObjectSimple>
 
 
 
+=item * Perl::Examples::Accessors::Hash (perl_code)
+
+L<Perl::Examples::Accessors::Hash>
+
+
+
+=item * Perl::Examples::Accessors::Moo (perl_code)
+
+L<Perl::Examples::Accessors::Moo>
+
+
+
+=item * Perl::Examples::Accessors::ClassInsideOut (perl_code)
+
+L<Perl::Examples::Accessors::ClassInsideOut>
+
+
+
 =item * Perl::Examples::Accessors::ClassAccessor (perl_code)
 
 L<Perl::Examples::Accessors::ClassAccessor>
 
 
 
+=item * Perl::Examples::Accessors::ClassXSAccessorArray (perl_code)
+
+L<Perl::Examples::Accessors::ClassXSAccessorArray>
+
+
+
+=item * Perl::Examples::Accessors::Mouse (perl_code)
+
+L<Perl::Examples::Accessors::Mouse>
+
+
+
+=item * Perl::Examples::Accessors::Array (perl_code)
+
+L<Perl::Examples::Accessors::Array>
+
+
+
+=item * Perl::Examples::Accessors::ClassXSAccessor (perl_code)
+
+L<Perl::Examples::Accessors::ClassXSAccessor>
+
+
+
 =back
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.22.1 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
 Benchmark with default options (C<< bencher -m Accessors::ClassStartup >>):
 
- +-------------------------------------------------+-----------+------------------------+------------+---------+---------+
- | participant                                     | time (ms) | mod_overhead_time (ms) | vs_slowest | errors  | samples |
- +-------------------------------------------------+-----------+------------------------+------------+---------+---------+
- | Perl::Examples::Accessors::Moose                | 1.2e+02   | 117.5                  | 1          | 0.00054 | 20      |
- | Perl::Examples::Accessors::Moo                  | 21        | 18.5                   | 5.4        | 8.3e-05 | 20      |
- | Perl::Examples::Accessors::Mouse                | 17        | 14.5                   | 6.8        | 3.1e-05 | 20      |
- | Perl::Examples::Accessors::ClassInsideOut       | 10        | 7.5                    | 11         | 2.7e-05 | 20      |
- | Perl::Examples::Accessors::MojoBase             | 10        | 7.5                    | 11         | 2.9e-05 | 20      |
- | Perl::Examples::Accessors::ClassXSAccessorArray | 8.1       | 5.6                    | 14         | 5.8e-05 | 22      |
- | Perl::Examples::Accessors::ObjectSimple         | 7.7       | 5.2                    | 15         | 2.9e-05 | 20      |
- | Perl::Examples::Accessors::ClassAccessor        | 7.7       | 5.2                    | 15         | 6e-05   | 20      |
- | Perl::Examples::Accessors::ClassXSAccessor      | 7.4       | 4.9                    | 16         | 1.4e-05 | 23      |
- | Perl::Examples::Accessors::ClassAccessorArray   | 4.2       | 1.7                    | 28         | 3.2e-05 | 22      |
- | Perl::Examples::Accessors::Mo                   | 4.2       | 1.7                    | 28         | 2e-05   | 20      |
- | Perl::Examples::Accessors::Scalar               | 2.7       | 0.2                    | 43         | 1.5e-05 | 20      |
- | Perl::Examples::Accessors::Array                | 2.7       | 0.2                    | 43         | 1.8e-05 | 20      |
- | Perl::Examples::Accessors::Hash                 | 2.7       | 0.2                    | 44         | 1.3e-05 | 21      |
- | perl -e1 (baseline)                             | 2.5       | 0                      | 47         | 6.6e-06 | 21      |
- +-------------------------------------------------+-----------+------------------------+------------+---------+---------+
+ +-------------------------------------------------+-----------+------------------------+------------+-----------+---------+
+ | participant                                     | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors   | samples |
+ +-------------------------------------------------+-----------+------------------------+------------+-----------+---------+
+ | Perl::Examples::Accessors::Moose                |     200   |                  195.3 |        1   |   0.0029  |      20 |
+ | Perl::Examples::Accessors::Moo                  |      40   |                   35.3 |        5   |   0.00061 |      21 |
+ | Perl::Examples::Accessors::Mouse                |      27   |                   22.3 |        7.3 |   0.00014 |      21 |
+ | Perl::Examples::Accessors::ClassInsideOut       |      16   |                   11.3 |       12   |   0.00012 |      20 |
+ | Perl::Examples::Accessors::MojoBase             |      16   |                   11.3 |       13   | 3.7e-05   |      20 |
+ | Perl::Examples::Accessors::ObjectSimple         |      13   |                    8.3 |       15   |   0.0001  |      20 |
+ | Perl::Examples::Accessors::ClassXSAccessorArray |      13   |                    8.3 |       15   |   7e-05   |      20 |
+ | Perl::Examples::Accessors::ClassAccessor        |      12   |                    7.3 |       16   | 7.4e-05   |      20 |
+ | Perl::Examples::Accessors::ClassXSAccessor      |      12   |                    7.3 |       17   | 3.8e-05   |      20 |
+ | Perl::Examples::Accessors::ClassAccessorArray   |       6.8 |                    2.1 |       29   | 5.1e-05   |      20 |
+ | Perl::Examples::Accessors::Mo                   |       6.8 |                    2.1 |       29   | 1.6e-05   |      20 |
+ | Perl::Examples::Accessors::Hash                 |       6   |                    1.3 |       30   |   7e-05   |      22 |
+ | Perl::Examples::Accessors::Scalar               |       6   |                    1.3 |       30   |   0.00011 |      20 |
+ | Perl::Examples::Accessors::Array                |       5.4 |                    0.7 |       37   | 2.8e-05   |      20 |
+ | perl -e1 (baseline)                             |       4.7 |                    0   |       42   | 3.9e-05   |      20 |
+ +-------------------------------------------------+-----------+------------------------+------------+-----------+---------+
 
 =head1 DESCRIPTION
 
