@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::Construction;
 
-our $DATE = '2016-04-14'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2016-06-23'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -40,7 +40,7 @@ Bencher::Scenario::Accessors::Construction - Benchmark object construction
 
 =head1 VERSION
 
-This document describes version 0.06 of Bencher::Scenario::Accessors::Construction (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-04-14.
+This document describes version 0.07 of Bencher::Scenario::Accessors::Construction (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-06-23.
 
 =head1 SYNOPSIS
 
@@ -92,51 +92,11 @@ L<Perl::Examples::Accessors::Scalar> 0.05
 
 =over
 
-=item * Mouse (perl_code)
+=item * Moose (perl_code)
 
 Code template:
 
- Perl::Examples::Accessors::Mouse->new
-
-
-
-=item * Class::Accessor::Array (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::ClassAccessorArray->new
-
-
-
-=item * Mojo::Base (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::MojoBase->new
-
-
-
-=item * Class::XSAccessor (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::ClassXSAccessor->new
-
-
-
-=item * Moo (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Moo->new
-
-
-
-=item * no generator (array-based) (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Array->new
+ Perl::Examples::Accessors::Moose->new
 
 
 
@@ -156,35 +116,19 @@ Code template:
 
 
 
-=item * Moose (perl_code)
+=item * Mojo::Base (perl_code)
 
 Code template:
 
- Perl::Examples::Accessors::Moose->new
+ Perl::Examples::Accessors::MojoBase->new
 
 
 
-=item * Class::XSAccessor::Array (perl_code)
+=item * Class::Accessor::Array (perl_code)
 
 Code template:
 
- Perl::Examples::Accessors::ClassXSAccessorArray->new
-
-
-
-=item * no generator (hash-based) (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Hash->new
-
-
-
-=item * Class::InsideOut (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::ClassInsideOut->new
+ Perl::Examples::Accessors::ClassAccessorArray->new
 
 
 
@@ -196,6 +140,30 @@ Code template:
 
 
 
+=item * no generator (hash-based) (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Hash->new
+
+
+
+=item * Moo (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Moo->new
+
+
+
+=item * Class::InsideOut (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::ClassInsideOut->new
+
+
+
 =item * Class::Accessor (perl_code)
 
 Code template:
@@ -204,32 +172,64 @@ Code template:
 
 
 
+=item * Class::XSAccessor::Array (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::ClassXSAccessorArray->new
+
+
+
+=item * Mouse (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Mouse->new
+
+
+
+=item * no generator (array-based) (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Array->new
+
+
+
+=item * Class::XSAccessor (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::ClassXSAccessor->new
+
+
+
 =back
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.22.1 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
 Benchmark with default options (C<< bencher -m Accessors::Construction >>):
 
- +-----------------------------+-------------+-----------+------------+-----------------+---------+---------+
- | participant                 | rate (/s)   | time (μs) | vs_slowest | result_size (b) | errors  | samples |
- +-----------------------------+-------------+-----------+------------+-----------------+---------+---------+
- | Class::InsideOut            | 3.9e+05     | 2.6       | 1          | 144             | 6.7e-09 | 20      |
- | Moose                       | 9.4e+05     | 1.1       | 2.4        | 120             | 1.7e-09 | 20      |
- | Mo                          | 1.29865e+06 | 0.770029  | 3.36094    | 120             | 0       | 20      |
- | Moo                         | 1.66899e+06 | 0.599166  | 4.31938    | 120             | 0       | 20      |
- | Class::Accessor             | 1.81e+06    | 0.552     | 4.69       | 120             | 1.9e-10 | 23      |
- | Mouse                       | 1.89e+06    | 0.53      | 4.89       | 120             | 1.8e-10 | 28      |
- | no generator (array-based)  | 2.52e+06    | 0.397     | 6.52       | 64              | 1.6e-10 | 33      |
- | no generator (hash-based)   | 3.00673e+06 | 0.332587  | 7.78149    | 120             | 0       | 20      |
- | Object::Simple              | 3.06127e+06 | 0.326661  | 7.92265    | 120             | 0       | 20      |
- | Mojo::Base                  | 3.07997e+06 | 0.324679  | 7.97103    | 120             | 0       | 20      |
- | no generator (scalar-based) | 3.35e+06    | 0.298     | 8.67       | 72              | 1e-10   | 20      |
- | Class::Accessor::Array      | 3.38e+06    | 0.296     | 8.75       | 64              | 8.2e-11 | 32      |
- | Class::XSAccessor           | 5.05885e+06 | 0.197673  | 13.0924    | 120             | 0       | 20      |
- | Class::XSAccessor::Array    | 5.26215e+06 | 0.190036  | 13.6186    | 64              | 0       | 20      |
- +-----------------------------+-------------+-----------+------------+-----------------+---------+---------+
+ +-----------------------------+-----------+-----------+------------+-----------------+---------+---------+
+ | participant                 | rate (/s) | time (μs) | vs_slowest | result_size (b) |  errors | samples |
+ +-----------------------------+-----------+-----------+------------+-----------------+---------+---------+
+ | Class::InsideOut            |    170000 |     6     |       1    |             144 | 7.2e-09 |      27 |
+ | Moose                       |    520000 |     1.9   |       3.2  |             120 | 3.4e-09 |      20 |
+ | Mo                          |    730000 |     1.4   |       4.4  |             120 |   5e-09 |      20 |
+ | Moo                         |   1070000 |     0.933 |       6.43 |             120 | 4.2e-10 |      20 |
+ | Class::Accessor             |   1100000 |     0.93  |       6.4  |             120 | 1.7e-09 |      20 |
+ | Mouse                       |   1500000 |     0.66  |       9    |             120 | 1.6e-09 |      21 |
+ | no generator (array-based)  |   1700000 |     0.59  |      10    |              64 | 7.7e-10 |      24 |
+ | no generator (hash-based)   |   1900000 |     0.52  |      12    |             120 | 9.9e-10 |      22 |
+ | Object::Simple              |   1990000 |     0.503 |      11.9  |             120 | 9.1e-11 |      20 |
+ | Mojo::Base                  |   2020000 |     0.496 |      12.1  |             120 | 2.7e-10 |      22 |
+ | Class::Accessor::Array      |   2200000 |     0.46  |      13    |              64 | 8.3e-10 |      20 |
+ | no generator (scalar-based) |   2280000 |     0.438 |      13.7  |              72 | 1.8e-10 |      20 |
+ | Class::XSAccessor           |   3810000 |     0.262 |      22.9  |             120 | 1.1e-10 |      20 |
+ | Class::XSAccessor::Array    |   3900000 |     0.26  |      23    |              64 | 8.8e-10 |      20 |
+ +-----------------------------+-----------+-----------+------------+-----------------+---------+---------+
 
 =head1 DESCRIPTION
 
