@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::GeneratorStartup;
 
-our $DATE = '2016-04-14'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2016-06-23'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -35,7 +35,7 @@ Bencher::Scenario::Accessors::GeneratorStartup - Benchmark startup of various ac
 
 =head1 VERSION
 
-This document describes version 0.06 of Bencher::Scenario::Accessors::GeneratorStartup (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-04-14.
+This document describes version 0.07 of Bencher::Scenario::Accessors::GeneratorStartup (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-06-23.
 
 =head1 SYNOPSIS
 
@@ -63,49 +63,21 @@ L<Mo> 0.39
 
 L<Mojo::Base>
 
-L<Moo> 2.000002
+L<Moo> 2.001001
 
-L<Moose> 2.1405
+L<Moose> 2.1801
 
-L<Mouse> 2.4.2
+L<Mouse> v2.4.5
 
-L<Object::Simple> 3.15
+L<Object::Simple> 3.16
 
 =head1 BENCHMARK PARTICIPANTS
 
 =over
 
-=item * Mouse (perl_code)
+=item * Moose (perl_code)
 
-L<Mouse>
-
-
-
-=item * Class::Accessor::Array (perl_code)
-
-L<Class::Accessor::Array>
-
-
-
-=item * Mojo::Base (perl_code)
-
-L<Mojo::Base>
-
-
-
-=item * Class::XSAccessor (perl_code)
-
-L<Class::XSAccessor>
-
-
-
-=item * Moo (perl_code)
-
-L<Moo>
-
-
-
-=item *  (perl_code)
+L<Moose>
 
 
 
@@ -119,25 +91,15 @@ L<Mo>
 
 
 
-=item * Moose (perl_code)
+=item * Mojo::Base (perl_code)
 
-L<Moose>
+L<Mojo::Base>
 
 
 
-=item * Class::XSAccessor::Array (perl_code)
+=item * Class::Accessor::Array (perl_code)
 
-L<Class::XSAccessor::Array>
-
-
-
-=item *  (perl_code)
-
-
-
-=item * Class::InsideOut (perl_code)
-
-L<Class::InsideOut>
+L<Class::Accessor::Array>
 
 
 
@@ -147,36 +109,74 @@ L<Object::Simple>
 
 
 
+=item *  (perl_code)
+
+
+
+=item * Moo (perl_code)
+
+L<Moo>
+
+
+
+=item * Class::InsideOut (perl_code)
+
+L<Class::InsideOut>
+
+
+
 =item * Class::Accessor (perl_code)
 
 L<Class::Accessor>
 
 
 
+=item * Class::XSAccessor::Array (perl_code)
+
+L<Class::XSAccessor::Array>
+
+
+
+=item * Mouse (perl_code)
+
+L<Mouse>
+
+
+
+=item *  (perl_code)
+
+
+
+=item * Class::XSAccessor (perl_code)
+
+L<Class::XSAccessor>
+
+
+
 =back
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.22.1 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
 Benchmark with default options (C<< bencher -m Accessors::GeneratorStartup >>):
 
- +--------------------------+-----------+------------------------+------------+---------+---------+
- | participant              | time (ms) | mod_overhead_time (ms) | vs_slowest | errors  | samples |
- +--------------------------+-----------+------------------------+------------+---------+---------+
- | Moose                    | 1.1e+02   | 107.4                  | 1          | 0.00025 | 21      |
- | Mouse                    | 18        | 15.4                   | 6.3        | 5.8e-05 | 20      |
- | Moo                      | 14        | 11.4                   | 8          | 4.4e-05 | 20      |
- | Class::InsideOut         | 11        | 8.4                    | 10         | 5.1e-05 | 20      |
- | Mojo::Base               | 10        | 7.4                    | 11         | 1.4e-05 | 20      |
- | Class::XSAccessor::Array | 7.7       | 5.1                    | 14         | 1.7e-05 | 20      |
- | Object::Simple           | 7.6       | 5                      | 15         | 2.6e-05 | 20      |
- | Class::Accessor          | 7.4       | 4.8                    | 15         | 2e-05   | 20      |
- | Class::XSAccessor        | 7.2       | 4.6                    | 15         | 2.6e-05 | 20      |
- | Class::Accessor::Array   | 4.1       | 1.5                    | 27         | 1.8e-05 | 20      |
- | Mo                       | 4.1       | 1.5                    | 27         | 2.6e-05 | 20      |
- | perl -e1 (baseline)      | 2.6       | 0                      | 43         | 9.9e-06 | 20      |
- +--------------------------+-----------+------------------------+------------+---------+---------+
+ +--------------------------+-----------+------------------------+------------+-----------+---------+
+ | participant              | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors   | samples |
+ +--------------------------+-----------+------------------------+------------+-----------+---------+
+ | Moose                    |     200   |                  195.3 |        1   |   0.0028  |      23 |
+ | Mouse                    |      26   |                   21.3 |        7.3 | 8.5e-05   |      20 |
+ | Moo                      |      19   |                   14.3 |        9.9 |   9e-05   |      20 |
+ | Class::InsideOut         |      20   |                   15.3 |       10   |   0.00032 |      20 |
+ | Mojo::Base               |      16   |                   11.3 |       12   | 5.3e-05   |      20 |
+ | Object::Simple           |      13   |                    8.3 |       15   |   0.00011 |      20 |
+ | Class::XSAccessor::Array |      12   |                    7.3 |       15   | 7.1e-05   |      20 |
+ | Class::Accessor          |      12   |                    7.3 |       16   | 6.3e-05   |      20 |
+ | Class::XSAccessor        |      12   |                    7.3 |       16   | 5.2e-05   |      20 |
+ | Mo                       |       6.6 |                    1.9 |       29   | 1.4e-05   |      20 |
+ | Class::Accessor::Array   |       6.5 |                    1.8 |       29   | 2.5e-05   |      20 |
+ | perl -e1 (baseline)      |       4.7 |                    0   |       40   | 5.4e-06   |      20 |
+ +--------------------------+-----------+------------------------+------------+-----------+---------+
 
 =head1 DESCRIPTION
 
