@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::Get;
 
-our $DATE = '2016-04-14'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2016-06-23'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -50,7 +50,7 @@ Bencher::Scenario::Accessors::Get - Benchmark attribute read/get
 
 =head1 VERSION
 
-This document describes version 0.06 of Bencher::Scenario::Accessors::Get (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-04-14.
+This document describes version 0.07 of Bencher::Scenario::Accessors::Get (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-06-23.
 
 =head1 SYNOPSIS
 
@@ -98,51 +98,11 @@ L<Perl::Examples::Accessors::ObjectSimple> 0.05
 
 =over
 
-=item * Mouse (perl_code)
+=item * Moose (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::Mouse->new; $o->attr1(42); $o }; $o->attr1
-
-
-
-=item * Class::Accessor::Array (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::ClassAccessorArray->new; $o->attr1(42); $o }; $o->attr1
-
-
-
-=item * Mojo::Base (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::MojoBase->new; $o->attr1(42); $o }; $o->attr1
-
-
-
-=item * Class::XSAccessor (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessor->new; $o->attr1(42); $o }; $o->attr1
-
-
-
-=item * Moo (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::Moo->new; $o->attr1(42); $o }; $o->attr1
-
-
-
-=item * no generator (array-based) (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::Array->new; $o->attr1(42); $o }; $o->attr1
+ state $o = do { my $o = Perl::Examples::Accessors::Moose->new; $o->attr1(42); $o }; $o->attr1
 
 
 
@@ -154,35 +114,19 @@ Code template:
 
 
 
-=item * Moose (perl_code)
+=item * Mojo::Base (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::Moose->new; $o->attr1(42); $o }; $o->attr1
+ state $o = do { my $o = Perl::Examples::Accessors::MojoBase->new; $o->attr1(42); $o }; $o->attr1
 
 
 
-=item * Class::XSAccessor::Array (perl_code)
+=item * Class::Accessor::Array (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessorArray->new; $o->attr1(42); $o }; $o->attr1
-
-
-
-=item * no generator (hash-based) (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::Hash->new; $o->attr1(42); $o }; $o->attr1
-
-
-
-=item * Class::InsideOut (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::ClassInsideOut->new; $o->attr1(42); $o }; $o->attr1
+ state $o = do { my $o = Perl::Examples::Accessors::ClassAccessorArray->new; $o->attr1(42); $o }; $o->attr1
 
 
 
@@ -194,6 +138,30 @@ Code template:
 
 
 
+=item * no generator (hash-based) (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Hash->new; $o->attr1(42); $o }; $o->attr1
+
+
+
+=item * Moo (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Moo->new; $o->attr1(42); $o }; $o->attr1
+
+
+
+=item * Class::InsideOut (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ClassInsideOut->new; $o->attr1(42); $o }; $o->attr1
+
+
+
 =item * Class::Accessor (perl_code)
 
 Code template:
@@ -202,6 +170,38 @@ Code template:
 
 
 
+=item * Class::XSAccessor::Array (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessorArray->new; $o->attr1(42); $o }; $o->attr1
+
+
+
+=item * Mouse (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Mouse->new; $o->attr1(42); $o }; $o->attr1
+
+
+
+=item * no generator (array-based) (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Array->new; $o->attr1(42); $o }; $o->attr1
+
+
+
+=item * Class::XSAccessor (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessor->new; $o->attr1(42); $o }; $o->attr1
+
+
+
 =item * raw hash access (perl_code)
 
 Code template:
@@ -222,29 +222,29 @@ Code template:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.22.1 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
 Benchmark with default options (C<< bencher -m Accessors::Get >>):
 
- +----------------------------+-------------+-----------+------------+---------+---------+
- | participant                | rate (/s)   | time (ns) | vs_slowest | errors  | samples |
- +----------------------------+-------------+-----------+------------+---------+---------+
- | Class::Accessor            | 2.36532e+06 | 422.776   | 1          | 0       | 21      |
- | Class::InsideOut           | 3.7e+06     | 2.7e+02   | 1.5        | 3.3e-10 | 31      |
- | Mojo::Base                 | 5.54943e+06 | 180.199   | 2.34617    | 0       | 20      |
- | no generator (hash-based)  | 5.6e+06     | 1.8e+02   | 2.4        | 3e-10   | 21      |
- | Mo                         | 5.91e+06    | 169       | 2.5        | 1e-10   | 20      |
- | no generator (array-based) | 5.9e+06     | 1.7e+02   | 2.5        | 4.2e-10 | 20      |
- | Object::Simple             | 6.07934e+06 | 164.492   | 2.5702     | 0       | 20      |
- | Moose                      | 6.78218e+06 | 147.445   | 2.86734    | 0       | 22      |
- | Class::Accessor::Array     | 7.39237e+06 | 135.275   | 3.12532    | 0       | 20      |
- | Mouse                      | 1.35e+07    | 74.1      | 5.71       | 1.1e-11 | 33      |
- | Moo                        | 1.7e+07     | 59        | 7.2        | 1.5e-10 | 23      |
- | Class::XSAccessor          | 1.82681e+07 | 54.7401   | 7.72333    | 0       | 28      |
- | Class::XSAccessor::Array   | 2.20255e+07 | 45.402    | 9.31184    | 0       | 20      |
- | raw hash access            | 3.06869e+07 | 32.5872   | 12.9737    | 0       | 31      |
- | raw array access           | 4.78931e+07 | 20.8798   | 20.2481    | 0       | 22      |
- +----------------------------+-------------+-----------+------------+---------+---------+
+ +----------------------------+-----------+-----------+------------+---------+---------+
+ | participant                | rate (/s) | time (ns) | vs_slowest |  errors | samples |
+ +----------------------------+-----------+-----------+------------+---------+---------+
+ | Class::Accessor            |   1610000 |       622 |       1    | 2.1e-10 |      23 |
+ | Class::InsideOut           |   2170000 |       461 |       1.35 | 2.6e-10 |      20 |
+ | Mojo::Base                 |   3300000 |       310 |       2    | 7.7e-10 |      25 |
+ | Mo                         |   3500000 |       280 |       2.2  | 4.3e-10 |      24 |
+ | Object::Simple             |   3700000 |       270 |       2.3  | 7.8e-10 |      29 |
+ | no generator (hash-based)  |   3800000 |       260 |       2.4  | 4.2e-10 |      23 |
+ | no generator (array-based) |   3900000 |       250 |       2.5  | 4.4e-10 |      31 |
+ | Moose                      |   4300000 |       240 |       2.6  | 2.6e-10 |      20 |
+ | Class::Accessor::Array     |   4460000 |       224 |       2.78 | 1.4e-10 |      20 |
+ | Mouse                      |  10000000 |        96 |       6.5  | 9.9e-11 |      20 |
+ | Class::XSAccessor          |  13000000 |        77 |       8.1  | 6.3e-10 |      23 |
+ | Moo                        |  13000000 |        75 |       8.3  | 2.2e-10 |      20 |
+ | Class::XSAccessor::Array   |  16000000 |        63 |       9.9  | 2.2e-10 |      35 |
+ | raw hash access            |  22000000 |        46 |      14    | 4.4e-10 |      20 |
+ | raw array access           |  35000000 |        28 |      22    | 1.5e-10 |      26 |
+ +----------------------------+-----------+-----------+------------+---------+---------+
 
 =head1 DESCRIPTION
 
