@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::Set;
 
-our $DATE = '2016-04-14'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2016-06-23'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -50,7 +50,7 @@ Bencher::Scenario::Accessors::Set - Benchmark attribute write/set
 
 =head1 VERSION
 
-This document describes version 0.06 of Bencher::Scenario::Accessors::Set (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-04-14.
+This document describes version 0.07 of Bencher::Scenario::Accessors::Set (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-06-23.
 
 =head1 SYNOPSIS
 
@@ -98,51 +98,11 @@ L<Perl::Examples::Accessors::ObjectSimple> 0.05
 
 =over
 
-=item * Mouse (perl_code)
+=item * Moose (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::Mouse->new; $o }; $o->attr1(42)
-
-
-
-=item * Class::Accessor::Array (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::ClassAccessorArray->new; $o }; $o->attr1(42)
-
-
-
-=item * Mojo::Base (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::MojoBase->new; $o }; $o->attr1(42)
-
-
-
-=item * Class::XSAccessor (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessor->new; $o }; $o->attr1(42)
-
-
-
-=item * Moo (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::Moo->new; $o }; $o->attr1(42)
-
-
-
-=item * no generator (array-based) (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::Array->new; $o }; $o->attr1(42)
+ state $o = do { my $o = Perl::Examples::Accessors::Moose->new; $o }; $o->attr1(42)
 
 
 
@@ -154,35 +114,19 @@ Code template:
 
 
 
-=item * Moose (perl_code)
+=item * Mojo::Base (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::Moose->new; $o }; $o->attr1(42)
+ state $o = do { my $o = Perl::Examples::Accessors::MojoBase->new; $o }; $o->attr1(42)
 
 
 
-=item * Class::XSAccessor::Array (perl_code)
+=item * Class::Accessor::Array (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessorArray->new; $o }; $o->attr1(42)
-
-
-
-=item * no generator (hash-based) (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::Hash->new; $o }; $o->attr1(42)
-
-
-
-=item * Class::InsideOut (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::ClassInsideOut->new; $o }; $o->attr1(42)
+ state $o = do { my $o = Perl::Examples::Accessors::ClassAccessorArray->new; $o }; $o->attr1(42)
 
 
 
@@ -194,6 +138,30 @@ Code template:
 
 
 
+=item * no generator (hash-based) (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Hash->new; $o }; $o->attr1(42)
+
+
+
+=item * Moo (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Moo->new; $o }; $o->attr1(42)
+
+
+
+=item * Class::InsideOut (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ClassInsideOut->new; $o }; $o->attr1(42)
+
+
+
 =item * Class::Accessor (perl_code)
 
 Code template:
@@ -202,6 +170,38 @@ Code template:
 
 
 
+=item * Class::XSAccessor::Array (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessorArray->new; $o }; $o->attr1(42)
+
+
+
+=item * Mouse (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Mouse->new; $o }; $o->attr1(42)
+
+
+
+=item * no generator (array-based) (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Array->new; $o }; $o->attr1(42)
+
+
+
+=item * Class::XSAccessor (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessor->new; $o }; $o->attr1(42)
+
+
+
 =item * raw hash access (perl_code)
 
 Code template:
@@ -222,29 +222,29 @@ Code template:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.22.1 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
 Benchmark with default options (C<< bencher -m Accessors::Set >>):
 
- +----------------------------+-------------+-----------+------------+---------+---------+
- | participant                | rate (/s)   | time (ns) | vs_slowest | errors  | samples |
- +----------------------------+-------------+-----------+------------+---------+---------+
- | Class::Accessor            | 1.8e+06     | 5.5e+02   | 1          | 6.2e-10 | 20      |
- | Class::InsideOut           | 3.04133e+06 | 328.803   | 1.67054    | 0       | 20      |
- | no generator (hash-based)  | 4.5e+06     | 222       | 2.47       | 1e-10   | 20      |
- | no generator (array-based) | 4.95e+06    | 202       | 2.72       | 1e-10   | 20      |
- | Mojo::Base                 | 5.1e+06     | 1.9e+02   | 2.8        | 4.1e-10 | 21      |
- | Moose                      | 5.20602e+06 | 192.085   | 2.85956    | 0       | 20      |
- | Mo                         | 5.37543e+06 | 186.032   | 2.95261    | 0       | 20      |
- | Class::Accessor::Array     | 5.64654e+06 | 177.099   | 3.10153    | 0       | 22      |
- | Object::Simple             | 5.73427e+06 | 174.39    | 3.14972    | 0       | 20      |
- | Mouse                      | 8.5e+06     | 118       | 4.67       | 5.2e-11 | 20      |
- | Class::XSAccessor          | 1.2e+07     | 81        | 6.8        | 2.1e-10 | 20      |
- | Moo                        | 1.27e+07    | 78.8      | 6.97       | 5.2e-11 | 20      |
- | Class::XSAccessor::Array   | 1.4e+07     | 69        | 7.9        | 1.8e-10 | 27      |
- | raw hash access            | 2.2e+07     | 45        | 12         | 1.5e-10 | 37      |
- | raw array access           | 2.72783e+07 | 36.6592   | 14.9834    | 0       | 20      |
- +----------------------------+-------------+-----------+------------+---------+---------+
+ +----------------------------+-----------+-----------+------------+---------+---------+
+ | participant                | rate (/s) | time (ns) | vs_slowest |  errors | samples |
+ +----------------------------+-----------+-----------+------------+---------+---------+
+ | Class::Accessor            |   1100000 |       950 |       1    | 1.7e-09 |      20 |
+ | Class::InsideOut           |   1770000 |       564 |       1.68 | 2.9e-10 |      20 |
+ | no generator (hash-based)  |   2800000 |       360 |       2.6  |   1e-09 |      20 |
+ | Mojo::Base                 |   3010000 |       332 |       2.86 | 2.8e-10 |      20 |
+ | no generator (array-based) |   3020000 |       332 |       2.86 |   1e-10 |      20 |
+ | Object::Simple             |   3190000 |       313 |       3.03 | 1.9e-10 |      31 |
+ | Moose                      |   3210000 |       311 |       3.05 | 2.1e-10 |      20 |
+ | Mo                         |   3360000 |       298 |       3.19 |   9e-11 |      20 |
+ | Class::Accessor::Array     |   3410000 |       294 |       3.23 | 1.5e-10 |      20 |
+ | Mouse                      |   5460000 |       183 |       5.19 | 1.5e-10 |      24 |
+ | Moo                        |   8000000 |       130 |       7.6  | 1.4e-10 |      26 |
+ | Class::XSAccessor          |   8400000 |       120 |       7.9  | 1.5e-10 |      20 |
+ | Class::XSAccessor::Array   |  10000000 |       100 |       9.5  | 2.1e-10 |      20 |
+ | raw hash access            |  17000000 |        60 |      16    | 3.5e-10 |      20 |
+ | raw array access           |  20000000 |        50 |      20    |   7e-10 |      33 |
+ +----------------------------+-----------+-----------+------------+---------+---------+
 
 =head1 DESCRIPTION
 
